# FreeGenes Python

FreeGenes Python (freegenes) is the Python API for working with <a href="https://www.github.com/vsoch/freegenes" target="_blank">FreeGenes</a>. See
the [documentation](https://vsoch.github.io/freegenes) for installation and usage. The package
will be released on [pypi](https://pypi.org/project/freegenes/) and eventually conda.

## License

This code is licensed under the MPL 2.0 [LICENSE](LICENSE).

## Help and Contribution

Please contribute to the package, or post feedback and questions as <a href="https://github.com/vsoch/freegenes" target="_blank">issues</a>.
